@@ -7,7 +7,8 @@
     
     #move opencpu system lib to the end of the search lib
     #note: removing a lib from which packages are already loaded results in weird behavior.
-    .libPaths(c(.Library.site, .Library, "/usr/lib/opencpu/library"));
+    #.libPaths(c(.Library.site, .Library, "/usr/lib/opencpu/library"));
+    #note undo this because of version conflicts with packages installed in global library
   
   } else if(interactive() && !("--slave" %in% commandArgs())){
     #Dont run in rscript
